/*
 * Project name:
     EEPROM Click (Advanced I2C Example)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Description:
     This example features the advanced communication with the 24AA01 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out via UART.
* Test configuration:
     MCU:             FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       Clicker 2 for FT900
                       http://www.mikroe.com/ft90x/clicker-2/
     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. modules:    EEPROM click board - ac:EEPROM
                      UART USB click board - ac:UART
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Place EEPROM click into mikroBUS socket1.
     - I2C address of EEPROM chip is 0xA2 (default).
     - Place USB UART click into socket2
     - Watch results over USART Terminal (use CR for line settings)
 */

#include "EEPROM_24AA01.h"

char someData[14] = "I2C mikroE";
char writeData[14];
char i, tmpdata;

//  Main
void main() {
  EEPROM_24AA01_Init();                                   // performs I2C initialization
  UART1_Init(56000);

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  UART1_Write_Text("Writing Single Byte");
  UART1_Write(13);
  Delay_ms(500);
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24AA01_WrSingle(i, tmpdata);                   // writes data, char by char, in the EEPROM
    Delay_ms(20);
  }
  UART1_Write_Text(someData);
  UART1_Write(13);

  EEPROM_24AA01_WrSingle(i+1, 0);                        // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  Delay_ms(1000);
  i = 1;
  tmpdata = 1;
  UART1_Write_Text("Reading Single Byte");
  UART1_Write(13);
  Delay_ms(500);

  while ((tmpdata = EEPROM_24AA01_RdSingle(i)) != 0) {   // reads data, char by char, from the EEPROM
    writeData[i-1] = tmpdata;
    Delay_ms(20);
    i++;
  }
  UART1_Write_Text(writeData);
  UART1_Write(13);

  //  Example for sequential data read
  Delay_ms(1000);
  EEPROM_24AA01_RdSeq(1, someData, 10);
  UART1_Write_Text("Sequential Reading");
  UART1_Write(13);
  UART1_Write_Text(someData);
  UART1_Write(13);
  Delay_ms(1000);
  UART1_Write_Text("EEPROM Test Successful!");
  UART1_Write(13);
}