/*
 * Project name:
     Pwm_Demo (Demo on using mikroE's PWM library functions)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Description:
    This is a simple demonstration of PWM library, which is being used for
    control of the FT900's PWM module. The module is initialized and started,
    after which the PWM's Duty Ratios can be adjusted by means of 2 buttons
    connected to pins P35, P2. The changes can be monitored on the PWM
    output pins P52.
 * Test configuration:
     MCU:             FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       Clicker 2 for FT900
                      http://www.mikroe.com/ft90x/clicker-2/
     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. modules:    None.
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - None.
 */

unsigned int current_duty;
unsigned int pwm_period;

void InitMain() {
  GPIO_Pin_Digital_Input(35);
  GPIO_Pin_Digital_Input(2);
}

void main() {

  InitMain();

  pwm_period = PWM_Init(250000);
  current_duty  = pwm_period / 2;                        // initial value for current_duty


  PWM_ConfigChannel(current_duty, _PWM_INIT_STATE_0, _PWM_CHANNEL_4);   // PWM output on P52 pin
  PWM_EnableOutput();

  while (1) {                                // endless loop
    if (!GPIO_PIN35_bit) {                   // button on P35 pressed
      Delay_ms(1);
      current_duty = current_duty + 5;       // increment current_duty
      if (current_duty > pwm_period) {       // if we increase current_duty greater then possible pwm_period1 value
        current_duty = 0;                    // reset current_duty value to zero
      }
     PWM_ConfigChannel(current_duty, _PWM_INIT_STATE_0, _PWM_CHANNEL_4);   // PWM output on P52 pin
     }

    if (!GPIO_PIN2_bit) {                    // button on P2 pressed
      Delay_ms(1);
      current_duty = current_duty - 5;       // decrement current_duty
      if (current_duty > pwm_period) {       // if we decrease current_duty greater then possible pwm_period1 value (overflow)
        current_duty = pwm_period;           // set current_duty to max possible value
      }
     PWM_ConfigChannel(current_duty, _PWM_INIT_STATE_0, _PWM_CHANNEL_4);   // PWM output on P52 pin
     }
    Delay_ms(100);                           // slow down change pace a little
  }
}