/*
 * Project name:
     Soft_UART (Demonstration of using Soft UART library routines)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Description:
     This code demonstrates how to use software UART library routines.
     Upon receiving data via RS232, MCU immediately sends it back to the sender.
  * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev. Board:      Clicker 2 for FT900
                      http://www.mikroe.com/ft90x/clicker-2/
     Oscillator:      CPU at full system clock, 100.000MHz
     ext. modules:    USB UART click - ac:UART_Click
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/FT90x/
 * NOTES:
      - Place USB UART click board into mikroBUS socket1.
      - Use USART Terminal for communication with controller.
 */

sfr sbit  Soft_Uart_RX_Pin at GPIO_PIN49_bit;
sfr sbit  Soft_Uart_TX_Pin at GPIO_PIN48_bit;

char i, error, byte_read;  // Auxiliary variables



void main() {
  GPIO_Pin_Digital_Output(34);
  error = Soft_UART_Init(56000, 0); // Initialize Soft UART at 56000 bps

  if (error > 0) {
    GPIO_PIN34_bit = 1;                       // Signalize Init error
    while(1);                                     // Stop program
  }
  Delay_ms(100);


  for (i = 'z'; i >= 'A'; i--) {                  // Send bytes from 'z' downto 'A'
    Soft_UART_Write(i);
    Delay_ms(100);
  }

  while(1) {                                      // Endless loop
    byte_read = Soft_UART_Read(&error);           // Read byte, then test error flag
    if (error)                                    // If error was detected
        GPIO_PIN34_bit = 1;
    else
      Soft_UART_Write(byte_read);                 // If error was not detected, return byte read
  }

}