/* Project name:
     CAN_2nd (can network demonstration)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
       - initial release;
 * Description:
     This code demonstrates how to use CAN library functions and procedures.
     It is used together with the CAN_1st example (on second MCU), and it can
     be used to test the connection of MCU to the CAN network.
     With minor adjustments, it should work with any other MCU that has a CAN module.
 * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7 - ac:CAN
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Connect USB cable and turn ON USB UART switches at SW2.2 and SW2.3 (board specific).
     - Turn on GPIO PORT 24-31 LEDs at SW8 (board specific).
     - Turn on CAN RX and TX switches at SW3.3 and SW3.4 (board specific).
     - Observe the exchange of data at GPIO PORT 24-31 and over USART terminal.
 */

#include "stdint.h"
#include "__Can.h"

char uart_rd;
unsigned long flags;
TCANMsg msg, rcv;
char txt[10];

void main()
{

  // Initialize UART module at 56000 bps
  UART1_Init(56000);
  // Wait for UART module to stabilize
  Delay_ms(100);
  UART1_Write_Text("Start the receiver");
  UART1_Write(13);
  UART1_Write(10);

  if (CAN_ERROR == CANx_Initialize(CAN1,1,40,6,3,0))
    UART1_Write_Text("canInit error");;       // init can0 module on 250kB bitrate

  if (CAN_ERROR == CAN_SetFilter(CAN1, 13 , DEFAULT))
    UART1_Write_Text("could not set filter");;       // init can0 module on 250kB bitrate

  while(1)
  {
     char
       count;
    if ( CANx_Read(CAN1, &msg.ID, &msg.buf, &msg.len, &flags) )
    {
       if (msg.len)
       {
         IntToStr(msg.buf[0],txt);
         UART1_Write_Text(txt);
         UART1_Write(13);
         UART1_Write(10);
         Delay_ms(500);

         msg.RTR = 0;
         msg.ID  = 112;
         msg.len = 1;
         flags   = 0;
         msg.buf[0]++;
        CANx_Write(CAN1, msg.ID, msg.buf, msg.len, flags);
       }
     }
  }
}