/* Project name:
     CAN_2nd (CAN network demonstration)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
       - initial release;
 * Description:
     This code demonstrates how to use CAN library functions and procedures.
     It is used together with the CAN_1st example (on second MCU), and it can
     be used to test the connection of MCU to the CAN network.
     With minor adjustments, it should work with any other MCU that has a CAN module.
 * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7 - ac:CAN
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Turn on GPIO PORT 32-39 LEDs at SW8 (board specific).
     - Turn on CAN RX and TX switches at SW3.3 and SW3.4 (board specific).
     - Observe the exchange of data at GPIO PORT 24-31 and over USART terminal.
 */

#include "stdint.h"
#include "__Can.h"

uint8_t
  uart_rd,
  txt[10];
uint32_t
  flags;
TCANMsg
  msg,
  rcv;

void main()
{
  GPIO_Digital_Output(&GPIO_PORT_32_39, _GPIO_PINMASK_ALL);
  GPIO_PORT_32_39 = 0;

  if (CAN_ERROR == CANx_Initialize(CAN1, 1, 40, 6, 3, 0))
  {
    // init can0 module on 250kB bitrate
    GPIO_PORT_32_39 = 0xAA;
  }
  if (CAN_ERROR == CAN_SetFilter(CAN1, 13 , DEFAULT))
  {
    GPIO_PORT_32_39 = 0x55;
  }

  while (1)
  {
     uint8_t
       count;
    if ( CANx_Read(CAN1, &msg.ID, &msg.buf, &msg.len, &flags) )
    {
       if (msg.len)
       {
         GPIO_PORT_32_39 = msg.buf[0];

         msg.RTR = 0;
         msg.ID  = 112;
         msg.len = 1;
         flags   = 0;

         msg.buf[0]++;
         Delay_ms(10);

         CANx_Write(CAN1, msg.ID, msg.buf, msg.len, flags);
       }
     }
  }
}