/*
 * Project name:
     EEPROM (Advanced I2C Example)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Description:
     This example features the advanced communication with the 24AA01 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out via UART.
* Test configuration:
     MCU:             FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       Clicker 2 for FT900
                      http://www.mikroe.com/easyft90x
     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. modules:    On-board ac:EEPROM module
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Turn On switches for UART communication TX (SW2.2) and  RX (SW2.3)
     - Turn On switches for I2C communication SDA(SW2.4) and SCL (SW2.5)
     - I2C address of EEPROM chip is 0x50 (default).
     - Watch results over USART Terminal (use CR for line settings)
 */

#include "EEPROM_24AA01.h"

char someData[] = "I2C_Advanced Test by mikroE";
char rData[28];
char i ,tmpdata;

//  Main
void main() {
  EEPROM_24AA01_Init();                      // performs I2C initialization

  UART1_Init(56000);
  UART1_Write_Text("Start");
  UART1_Write(13);
  UART1_Write(10);

  UART1_Write_Text("Write data to EEPROM:                         ");
  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24AA01_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    UART1_Write(tmpdata);
    Delay_ms(20);
  }
  EEPROM_24AA01_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  UART1_Write(13);
  UART1_Write(10);

  UART1_Write_Text("Read data from EEPROM (single receive mode):  ");
  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24AA01_RdSingle(i)) != 0) {
    UART1_Write(tmpdata);
    Delay_ms(20);
    i++ ;
  }
  UART1_Write(13);
  UART1_Write(10);

  // Example for burst read
  UART1_Write_Text("Read data from EEPROM (burst receive mode):   ");
  EEPROM_24AA01_RdSeq(1, rData, strlen(someData));
  UART1_Write_Text(rData);

  UART1_Write(13);
  UART1_Write(10);
  UART1_Write(13);
  UART1_Write(10);
}