/*
 * Project name:
     EEPROM (Advanced I2C Example)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Description:
     This program demonstrates usage of the I2C library routines. It
     establishes I2C bus communication with 24AA01 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORT 16-23.
* Test configuration:
     MCU:             FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7
                      http://www.mikroe.com/easyft90x

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. modules:    On-board ac:EEPROM module
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Turn On switches for I2C communication SDA(SW2.4) and SCL (SW2.5)
     - Turn ON PORT 16 - 23 LEDs at SW8.3. (board specific)
 */

char data_[256];


//--------------- Writes data to 24AA01 EEPROM - signle location
void EEPROM_24AA01_WrSingle(unsigned short wAddr, unsigned short wData) {
  data_[0] = wAddr;
  data_[1] = wData;
  I2CM1_Set_Slave_Address(0x50);
  I2CM1_Write_Bytes(data_,2);
}

//--------------- Reads data from 24AA01 EEPROM - single location (random)
unsigned short EEPROM_24AA01_RdSingle(unsigned short rAddr) {
  data_[0] = rAddr;
  I2CM1_Set_Slave_Address(0x50);
  I2CM1_Write(rAddr);
  I2CM1_Read(data_);

  return data_[0];
}

void main(){
  unsigned short i;

  GPIO_Digital_Output(&GPIO_PORT_16_23, _GPIO_PINMASK_ALL);

  I2CM1_Init(_I2CM_SPEED_MODE_STANDARD, _I2CM_SWAP_DISABLE);      // performs I2C initialization

  GPIO_PORT_16_23 = 0xFF;
  Delay_ms(1000);

  for(i = 0; i<0x80; i++) {
    EEPROM_24AA01_WrSingle(i,i);
    GPIO_PORT_16_23++;
    delay_ms(5);
  }

  Delay_ms(500);
  GPIO_PORT_16_23 = 0xFF;
  Delay_ms(1000);

  for(i = 0x00; i < 0x80; i++){
    GPIO_PORT_16_23 = EEPROM_24AA01_RdSingle(i);
    delay_ms(100);
  }

}