/* Project name:
     Joystick
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20111125:
       - initial release;
 * Description:
     This example presents features of the joystick input device.
 * Test configuration:
      Device:         FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
      Dev.Board:      EasyFT90x v7
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. Modules:    EasyTFT - ac:EasyTFT
     
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Pull Up on GPIO Pins 62, 63, 64, 65, 66.

*/
#include "built_in.h"
// TFT module connections
char TFT_DataPort at GPIO_PORT_32_39;
sbit TFT_RST at GPIO_PIN42_bit;
sbit TFT_RS at GPIO_PIN40_bit;
sbit TFT_CS at GPIO_PIN41_bit;
sbit TFT_RD at GPIO_PIN46_bit;
sbit TFT_WR at GPIO_PIN47_bit;
// End TFT module connections

unsigned int oldstate_press, oldstate_right, oldstate_left, oldstate_up, oldstate_down;
unsigned int state;

void Auxiliary_Code() {
  // Place your code here
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Set_Index(unsigned short index) {
  // Place your code here
  TFT_RS = 0;
  asm nop;
  TFT_DataPort = index;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Command(unsigned short cmd) {
  // Place your code here
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = cmd;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Data(unsigned int _data) {
  // Place your code here
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = Hi(_data);
  asm nop; asm nop;
  Auxiliary_Code();
  asm nop;
  TFT_DataPort = Lo(_data);
  asm nop; asm nop;
  Auxiliary_Code();
}

void Init_MCU() {

  GPIO_Pin_Digital_Input(_GPIO_PIN_NUM_64); // Set Up as digital input
  GPIO_Pin_Digital_Input(_GPIO_PIN_NUM_65); // Set Center as digital input
  GPIO_Pin_Digital_Input(_GPIO_PIN_NUM_66); // Set Left as digital input
  GPIO_Pin_Digital_Input(_GPIO_PIN_NUM_63); // Set Right as digital input
  GPIO_Pin_Digital_Input(_GPIO_PIN_NUM_62); // Set Down as digital input

  Delay_100ms();
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_ILI9341_8bit(320, 240);
}

void main() {

  Init_MCU();
  TFT_Fill_Screen(CL_TEAL);
  TFT_Write_Text("Press joystik on board", 75, 80);
  TFT_Write_Text("and MCU will detect direction.", 75, 110);

  oldstate_press = 0;
  oldstate_right = 0;
  oldstate_left  = 0;
  oldstate_up    = 0;
  oldstate_down  = 0;
  state = 1;

  while(1){

    if (Button (&GPIO_PORT_64_66, 1, 1, 1))                     // detect logical one state
      oldstate_press = 1;
    if (oldstate_press && Button(&GPIO_PORT_64_66, 1, 1, 0)) { // detect logical one to logical zero transition
      TFT_Fill_Screen(CL_TEAL);
      TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
      TFT_Circle(160, 114, 40);
      TFT_Write_Text("Pressed", 136, 106);
      Delay_ms(300);
      TFT_Fill_Screen(CL_TEAL);
      oldstate_press = 0;
      state = 1;
    }

    if (Button(&GPIO_PORT_56_63, 7, 1, 1))                     // detect logical one state
      oldstate_right = 1;
    if (oldstate_right && Button(&GPIO_PORT_56_63, 7, 1, 0)) { // detect logical one to logical zero transition
      TFT_Fill_Screen(CL_TEAL);
      TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
      TFT_Circle(282, 114, 20);
      TFT_Write_Text("Right", 266, 106);
      Delay_ms(300);
      TFT_Fill_Screen(CL_TEAL);
      oldstate_right = 0;
      state = 2;
    }

    if (Button(&GPIO_PORT_64_66, 2, 1, 1))
      oldstate_left = 1;
    if (oldstate_left && Button(&GPIO_PORT_64_66, 2, 1, 0)) { // detect logical one to logical zero transition
      TFT_Fill_Screen(CL_TEAL);
      TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
      TFT_Circle(28, 114, 20);
      TFT_Write_Text("Left", 16, 106);
      Delay_ms(300);
      TFT_Fill_Screen(CL_TEAL);
      oldstate_left = 0;
      state = 3;
    }

    if (Button(&GPIO_PORT_64_66, 0, 1, 1))                  // detect logical one state
      oldstate_up = 1;
    if (oldstate_up && Button(&GPIO_PORT_64_66, 0, 1, 0)) { // detect logical one to logical zero transition
      TFT_Fill_Screen(CL_TEAL);
      TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
      TFT_Circle(154, 24, 20);
      TFT_Write_Text("Up", 146, 16);
      Delay_ms(300);
      TFT_Fill_Screen(CL_TEAL);
      oldstate_up = 0;
      state = 4;
    }

    if (Button(&GPIO_PORT_56_63, 6, 1, 1))
      oldstate_down = 1;
    if (oldstate_down && Button(&GPIO_PORT_56_63, 6, 1, 0)) { // detect logical one to logical zero transition
      TFT_Fill_Screen(CL_TEAL);
      TFT_Set_Brush(1, CL_RED, 0, 0, 0, 0);
      TFT_Circle(154, 216, 20);
      TFT_Write_Text("Down", 138, 207);
      Delay_ms(300);
      TFT_Fill_Screen(CL_TEAL);
      oldstate_down = 0;
      state = 5;
    }
  }
}