/* Project name:
     Sound (Usage of Sound library)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
       - initial release;
 * Description:
     This project is a simple demonstration of how to
     use sound library for playing tones on a piezo speaker.
 * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7 - ac:Buzzer
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Pull down on GPIO PIN 24 - 28 (board specific).
     - Button press level in Vcc position on GPIO 24-31 on SW1 (board specific).
     - Turn on Buzzer at SW6 (board specific).
 */

/**
 * frequency = 659Hz, duration = 250ms
 */
void Tone1()
{
  Sound_Play(659, 250);
}

/**
 * frequency = 698Hz, duration = 250ms
 */
void Tone2()
{
  Sound_Play(698, 250);
}

/**
 * frequency = 784Hz, duration = 250ms
 */
void Tone3()
{
  Sound_Play(784, 250);
}

/**
 * play the melody "Yellow house"
 */
void Melody()
{
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone3(); Tone3(); Tone2(); Tone2(); Tone1();
}

/**
 * frequency = 880Hz, duration = 50ms
 */
void ToneA()
{
  Sound_Play( 880, 50);
}

/**
 * frequency = 1046, duration = 50ms
 */
void ToneC()
{
  Sound_Play(1046, 50);
}

/**
 * frequency = 1318Hz, duration = 50ms
 */
void ToneE()
{
  Sound_Play(1318, 50);
}

/**
 * play the melody A-C-E
 */
void Melody2()
{
  unsigned short i;
  for (i = 9; i > 0; i--)
  {
    ToneA(); ToneC(); ToneE();
  }
}

void main()
{
  // Set GPIO PIN 24 - 31 as digital input
  GPIO_Digital_Input(&GPIO_PORT_24_31, _GPIO_PINMASK_0 | _GPIO_PINMASK_1 | _GPIO_PINMASK_2 | _GPIO_PINMASK_3 | _GPIO_PINMASK_4);

  Sound_Init(&GPIO_PORT_48_55, _GPIO_PIN_NUM_7);
 
  // Play sound at 880Hz for 1 second
  Sound_Play(880, 1000);

  while (1)
  {
    // RB7 plays Tone1
    if ( Button(&GPIO_PORT_24_31, 4, 1, 1) )
    {
      Tone1();
    }
    // Wait for button to be released
    while (GPIO_PIN28_bit == 1) {}

    // RB6 plays Tone2
    if ( Button(&GPIO_PORT_24_31, 3, 1, 1) )
    {
      Tone2();
    }
    // Wait for button to be released
    while (GPIO_PIN27_bit == 1) {}

    // RB5 plays Tone3
    if ( Button(&GPIO_PORT_24_31, 2, 1, 1) )
    {
      Tone3();
    }
    // Wait for button to be released
    while (GPIO_PIN26_bit == 1) {}

    // RB4 plays Melody2
    if ( Button(&GPIO_PORT_24_31, 1, 1, 1) )
    {
      Melody2();
    }
    // Wait for button to be released
    while (GPIO_PIN25_bit == 1) {}

    // RB3 plays Melody
    if ( Button(&GPIO_PORT_24_31, 0, 1, 1) )
    {
      Melody();
    }
    // Wait for button to be released
    while (GPIO_PIN24_bit == 1) {}
  }
}