/* Project name:
     TouchPanel - calibration (demo for working with touchPanel controller)
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     - initial release;
 * Description:
     This code works with TouchPanel and GLCD. Two digital output and
     two analog input signals are used for communication with TouchPanel.
     The example shows how to calibrate touch panel.

 * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. Modules:    Touch_Panel - ac:Touch_Panel

     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/

 * NOTES:
     - Turn ON Back Light switch at SW5.8.
     - Turn ON Touch Panel controller switches at SW6.
 */

// Glcd module connections
unsigned long GLCD_DataPort  at GPIO_PORT_32_39;
sbit GLCD_CS1 at GPIO_PIN46_bit;
sbit GLCD_CS2 at GPIO_PIN47_bit;
sbit GLCD_RS  at GPIO_PIN40_bit;
sbit GLCD_RW  at GPIO_PIN5_bit;
sbit GLCD_EN  at GPIO_PIN41_bit;
sbit GLCD_RST at GPIO_PIN42_bit;
// End Glcd module connections

// Touch Panel module connections
sbit DriveA at GPIO_PIN31_bit;
sbit DriveB at GPIO_PIN43_bit;
// End Touch Panel module connections


const char msg1[] = "TOUCH BOTTOM LEFT";
const char msg2[] = "                 ";
const char msg3[] = "TOUCH UPPER RIGHT";
const char msg4[] = "CALIBRATION";
const char msg5[] = "Calibration constants";
char msg[22];

unsigned int x_min, y_min, x_max, y_max;           // Calibration constants

char x_min_msg[] = "X min:";                       // GLCD text messages
char y_min_msg[] = "Y min:";
char x_max_msg[] = "X max:";
char y_max_msg[] = "Y max:";

char x_min_val[6];                                 // Calibration constants string values
char y_min_val[6];
char x_max_val[6];
char y_max_val[6];

// copy const to ram string
char * CopyConst2Ram(char * dest, const char * src){
  char * d ;
  d = dest;
  for(;*dest++ = *src++;)
    ;
  return d;
}

void Initialize() {
  Glcd_Init();                                     // Initialize GLCD
  Glcd_Fill(0);                                    // Clear GLCD

  ADC_Set_Input_Channel(_ADC_CHANNEL_6 | _ADC_CHANNEL_5);
  ADC_Init();

  TP_Init(128, 64, 6, 5);                          // Initialize touch panel
  TP_Set_ADC_Threshold(900);                       // Set touch panel ADC threshold
}

void Calibrate() {

  Glcd_Dot(0,63,1);                                // Draw bottom left dot
  Glcd_Write_Text(CopyConst2Ram(msg,msg1),12,3,1);
  TP_Calibrate_Bottom_Left();                      // Calibration of bottom left corner
  Delay_ms(1000);

  Glcd_Dot(0,63,0);                                // Clear bottom left dot
  Glcd_Dot(127,0,1);                               // Draw upper right dot
  Glcd_Write_Text(CopyConst2Ram(msg,msg2),12,3,1);
  Glcd_Write_Text(CopyConst2Ram(msg,msg3),12,4,1);
  TP_Calibrate_Upper_Right();                      // Calibration of upper right corner

  Delay_ms(1000);
}

void main() {

  Initialize();

  Glcd_Write_Text(CopyConst2Ram(msg,msg4),32,3,1);
  Delay_ms(1000);
  Glcd_Fill(0);                                    // Clear GLCD
  Calibrate();

  TP_Get_Calibration_Consts(&x_min, &x_max, &y_min, &y_max); // Get calibration constants

  WordToStr(x_min, x_min_val);                             // Convert calibration constants into string values
  WordToStr(x_max, x_max_val);
  WordToStr(y_min, y_min_val);
  WordToStr(y_max, y_max_val);

  // Display Calibration constants on GLCD

  Glcd_Fill(0);                                            // Clear GLCD
  Glcd_Write_Text(CopyConst2Ram(msg,msg5),1,1,1);
  Glcd_Write_Text(x_min_msg,1,3,1);                        // Write messages on GLCD
  Glcd_Write_Text(x_max_msg,1,4,1);
  Glcd_Write_Text(y_min_msg,1,5,1);
  Glcd_Write_Text(y_max_msg,1,6,1);

  Glcd_Write_Text(x_min_val,50,3,1);                       // Write calibration constants values on GLCD
  Glcd_Write_Text(x_max_val,50,4,1);
  Glcd_Write_Text(y_min_val,50,5,1);
  Glcd_Write_Text(y_max_val,50,6,1);

}